
local moduleName = "party"
local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames_Party')
local Party = SimpleUnitFrames:NewModule(moduleName, "AceEvent-2.0")

L:RegisterTranslations('enUS', function() return {

	["Party Frame"] = true,
	["Description"] = "Options for the party frame",
	["Middle Health Text"] = true,
	["Right Health Text"] = true,
	["Middle Mana Text"] = true,
	["Right Mana Text"] = true,
	["Middle Health Text Description"] = "Set middle health text to one of the formats",
	["Right Health Text Description"] = "Set right health text to one of the formats",
	["Middle Mana Text Description"] = "Set middle mana text to one of the formats",
	["Right Mana Text Description"] = "Set right health text to one of the formats",
	
} end)

L:RegisterTranslations('koKR', function() return {

	["Party Frame"] = "파티 프레임",
	["Description"] = "파티 프레임에 대한 설정",
	["Middle Health Text"] = "중간 생명력 글자",
	["Right Health Text"] = "오른쪽 생명력 글자",
	["Middle Mana Text"] = "중간 마나 글자",
	["Right Mana Text"] = "오른쪽 마나 글자",
	["Middle Health Text Description"] = "중간 생명력 글자 표시 방법 선택",
	["Right Health Text Description"] = "오른쪽 생명력 글자 표시 방법 선택",
	["Middle Mana Text Description"] = "중간 마나 글자 표시 방법 선택",
	["Right Mana Text Description"] = "오른쪽 마나 글자 표시 방법 선택",
	
} end)



function Party:GetConsoleOptions()
	local OPTION_ORDER = 100
	return {
		type = 'group',
		name = L['Party Frame'],
		desc = L['Description'],
		args = {	
			mhp = {
				order = OPTION_ORDER + 1,
				type = 'text',
				name = L['Middle Health Text'],
				desc = L['Middle Health Text Description'],
				get = function() return self.db.profile.mhp end,
				set = function(v) 
								self.db.profile.mhp = v
								self:Refresh()
							end,
				validate = self.core.formatList,
			},
			rhp = {
				order = OPTION_ORDER + 2,
				type = 'text',
				name = L['Right Health Text'],
				desc = L['Right Health Text Description'],
				get = function() return self.db.profile.rhp end,
				set = function(v) 
								self.db.profile.rhp = v
								self:Refresh()
							end,
				validate = self.core.formatList,
			},
			mmp = {
				order = OPTION_ORDER + 3,
				type = 'text',
				name = L['Middle Mana Text'],
				desc = L['Middle Mana Text Description'],
				get = function() return self.db.profile.mmp end,
				set = function(v)
								self.db.profile.mmp = v
								self:Refresh()
							end,
				validate = self.core.formatList,
			},
			rmp = {
				order = OPTION_ORDER + 4,
				type = 'text',
				name = L['Right Mana Text'],
				desc = L['Right Mana Text Description'],
				get = function() return self.db.profile.rmp end,
				set = function(v)
								self.db.profile.rmp = v
								self:Refresh()
							end,
				validate = self.core.formatList,
			},
		}
	}

end


function Party:OnInitialize()
	self.db = SimpleUnitFrames:AcquireDBNamespace(moduleName)

	SimpleUnitFrames:RegisterDefaults(moduleName, 'profile', {
		mhp = "percenthp",
		rhp = "currmaxhp",
		mmp = "percentmp",
		rmp = "currmaxmp",
	} )
	

	self.frames = {}
	for i=1, 5, 1 do 
		local unitid = 'party' .. i
		local partyFrame = getglobal("PartyMemberFrame" .. i )
		
		local frame = CreateFrame("Frame", nil, partyFrame)
		frame:SetFrameLevel(3)
		frame:SetPoint("TOPLEFT", partyFrame, "TOPLEFT", 25, -5)
		frame:SetHeight(20)
		frame:SetWidth(120)
		self.frames[unitid] = frame
		
		local fontString
		
		-- Middle Health Text.
		fontString = 	frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
		fontString:SetPoint("TOP", frame, "TOP", 0, -4)
		frame.mhpText = fontString
		
		-- Right Health Text.
		fontString = 	frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
		fontString:SetPoint("TOPLEFT", frame, "TOPLEFT", 100, -4)
		frame.rhpText = fontString
		
		-- Middle Health Text.
		fontString = 	frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
		fontString:SetPoint("TOP", frame, "TOP", 0, -14)
		frame.mmpText = fontString
		
		-- Right Health Text.
		fontString = 	frame:CreateFontString(nil, "OVERLAY", "GameFontHighlightSmall")
		fontString:SetPoint("TOPLEFT", frame, "TOPLEFT", 100, -14)
		frame.rmpText = fontString
	end
	
	self.frames.party1:SetScript("OnShow", function() self:OnShow() end )
	self.frames.party1:SetScript("OnHide", function() self:OnHide() end )

end



function Party:OnShow()

	if self.db then
		self:RegisterEvent("PARTY_MEMBERS_CHANGED", "Refresh");
		self:RegisterEvent("UNIT_HEALTH", "OnHealthChange" )
		self:RegisterEvent("UNIT_MAXHEALTH", "OnHealthChange" )
		self:RegisterEvent("UNIT_MANA", "OnManaChange" )
		self:RegisterEvent("UNIT_MAXMANA", "OnManaChange")
		self:RegisterEvent("UNIT_ENERGY", "OnManaChange")
		self:RegisterEvent("UNIT_MAXENERGY", "OnManaChange")
		self:RegisterEvent("UNIT_RAGE", "OnManaChange")
		self:RegisterEvent("UNIT_MAXRAGE", "OnManaChange")
		self:RegisterEvent("UNIT_DISPLAYPOWER", "OnManaChange")		
		self:Refresh()
	end

end

function Party:OnHide()

	self:UnregisterAllEvents()
	
end

function Party:Refresh()
	for i=1, GetNumPartyMembers(), 1 do
		local unitid = 'party' .. i
		if UnitExists(unitid) then
			self:UpdateHealth(unitid)
			self:UpdateMana(unitid)
		end
	end
end

function Party:OnHealthChange(arg1)
	if string.find(arg1, '^party%d$') then
		self:UpdateHealth(arg1)
	end
end

function Party:OnManaChange(arg1)
	if string.find(arg1, '^party%d$') then
		self:UpdateMana(arg1)
	end
end
		

function Party:UpdateHealth(unitid)
	self.frames[unitid].mhpText:SetText( self:GetValueText(unitid, self.db.profile.mhp) )
	self.frames[unitid].rhpText:SetText( self:GetValueText(unitid, self.db.profile.rhp) )
end

function Party:UpdateMana(unitid)
	self.frames[unitid].mmpText:SetText( self:GetValueText(unitid, self.db.profile.mmp) )
	self.frames[unitid].rmpText:SetText( self:GetValueText(unitid, self.db.profile.rmp) )
end
